summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc/SpellDialogChildWindow.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc/SpellDialogChildWindow.hxx')
-rwxr-xr-xsd/source/ui/inc/SpellDialogChildWindow.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sd/source/ui/inc/SpellDialogChildWindow.hxx b/sd/source/ui/inc/SpellDialogChildWindow.hxx
index 4e08dd99b063..21d0a9882b94 100755
--- a/sd/source/ui/inc/SpellDialogChildWindow.hxx
+++ b/sd/source/ui/inc/SpellDialogChildWindow.hxx
@@ -45,7 +45,7 @@ class SpellDialogChildWindow
public:
SpellDialogChildWindow (
::Window* pParent,
- USHORT nId,
+ sal_uInt16 nId,
SfxBindings* pBindings,
SfxChildWinInfo* pInfo);
virtual ~SpellDialogChildWindow (void);
@@ -77,7 +77,7 @@ private:
*/
Outliner* mpSdOutliner;
/** When this flag is <TRUE/> then eventually we have to destroy
the outliner in mpSdOutliner.
*/
bool mbOwnOutliner;
@@ -77,7 +77,7 @@ private:
*/
Outliner* mpSdOutliner;
- /** When this flag is <TRUE/> then eventually we have to destroy
+ /** When this flag is <sal_True/> then eventually we have to destroy
the outliner in mpSdOutliner.
*/